# xml-to-chain-dict
An effective, powerful, fast and simple XML Python parsing tool.

`online tutorial`：http://101.34.219.31:8001/

# 注：
0.2.2.2 版本（包含）之前的代码为测试版，不稳定；
0.2.3.1 版本（包含）往后的代码为正式版，提供稳定的解析引擎。
0.2.3.2：修复使用 tag 搜索时双倍结果的 BUG；修复新增属性时整型赋值问题。

## 若您有意参与本工具的开发，请直接联系：jiyangj@foxmail.com，期待您的意见。
